@@ -43,6 +43,9 @@ def main(args):
         print 'usage: %s uri' % sys.argv[0]
         return -1
 
+    # GObject threads initialization
+    gobject.threads_init()
+
     # OpenGL viewport creation
     gl = pgm.viewport_factory_make('opengl')
     gl.title = 'Video cloning'
