@@ -24,6 +24,18 @@
 import sys, pgm, gobject
 from gtk import gdk
 
+# Show state changes
+def on_state(viewport, event):
+    if event.state_mask & pgm.VIEWPORT_ICONIFIED:
+        print 'iconified'
+    else:
+        print 'deiconified'
+
+# Key press handler
+def on_key_press(viewport, event):
+    if event.keyval == pgm.keysyms.i:
+        viewport.iconified = not viewport.iconified
+
 # Terminate the mainloop on a delete event
 def on_delete(viewport, event):
     pgm.main_quit()
@@ -62,6 +74,8 @@ def main(args):
 
     # Let's connect our callbacks and start the mainloop
     gl.connect('delete-event', on_delete)
+    gl.connect('key-press-event', on_key_press)
+    gl.connect('state-event', on_state)
     gl.show()
     pgm.main()
 
