@@ -29,7 +29,7 @@ def update_pass_cb(viewport, image, transformation):
     return True
 
 # Start animating the mapping matrix when the pixbuf is loaded
-def on_pixbuf_loaded(image, viewport, transformation):
+def on_file_loaded(image, viewport, transformation):
     viewport.connect('update-pass', update_pass_cb, image, transformation)
 
 # Terminate the mainloop on a delete event
@@ -38,6 +38,9 @@ def on_delete(viewport, event):
 
 # Entry point
 def main(args):
+    # GObject threads initialization
+    gobject.threads_init()
+
     # OpenGL viewport creation
     gl = pgm.viewport_factory_make('opengl')
     gl.connect('delete-event', on_delete)
@@ -58,7 +61,7 @@ def main(args):
     # Image creation
     img = pgm.Image()
     img.set_from_file('examples/pictures/meiko.jpg')
-    img.connect('pixbuf-loaded', on_pixbuf_loaded, gl, t)
+    img.connect('file-loaded', on_file_loaded, gl, t)
     img.size = (400, 400)
     img.position = (100, 100, 0)
     img.bg_color = (255, 255, 255, 0)
