@@ -43,10 +43,13 @@ def update_pass_cb(viewport, image):
     return True
 
 # Start animating the mapping matrix when the pixbuf is loaded
-def on_pixbuf_loaded(image, viewport):
+def on_file_loaded(image, viewport):
     viewport.connect('update-pass', update_pass_cb, image)
 
 def main(args):
+    # GObject threads initialization
+    gobject.threads_init()
+
     # OpenGL viewport creation
     viewport = pgm.viewport_factory_make('opengl')
     viewport.connect('key-press-event', on_key_press)
@@ -57,7 +60,7 @@ def main(args):
     img.position = (1.0, 0.5, 0.0)
     img.bg_color = (255, 255, 255, 0)
     img.set_from_file('examples/pictures/fluendo.png')
-    img.connect('pixbuf-loaded', on_pixbuf_loaded, viewport)
+    img.connect('file-loaded', on_file_loaded, viewport)
     img.show()
     cvs = pgm.Canvas()
     cvs.add(pgm.DRAWABLE_MIDDLE, img)
