@@ -39,6 +39,9 @@ def on_key_press(viewport, event):
         viewport.fullscreen = not viewport.fullscreen
 
 def main(args):
+    # GObject threads initialization
+    gobject.threads_init()
+
     # OpenGL viewport creation
     gl = pgm.viewport_factory_make('opengl')
     gl.title = 'Animated image'
