@@ -98,25 +98,25 @@ class Grid(Group):
     def _scrolled(self, drawable, x, y, z, direction, time):
         return self.emit('scrolled', x, y, z, direction, time)
 
-    def _drag_begin(self, drawable, x, y, z, button, time):
+    def _drag_begin(self, drawable, x, y, z, button, time, pressure):
         self._dragging = True
-        return self.emit('drag-begin', x, y, z, button, time)
+        return self.emit('drag-begin', x, y, z, button, time, pressure)
 
-    def _drag_motion(self, drawable, x, y, z, button, time):
+    def _drag_motion(self, drawable, x, y, z, button, time, pressure):
         time_since_last = time - self._last_drag_motion
         if time_since_last > self.drag_motion_resolution:
             self._last_drag_motion = time
-            return self.emit('drag-motion', x, y, z, button, time)
+            return self.emit('drag-motion', x, y, z, button, time, pressure)
 
     def _drag_end(self, drawable, x, y, z, button, time):
         self._dragging = False
         return self.emit('drag-end', x, y, z, button, time)
 
-    def _clicked(self, drawable, x, y, z, button, time):
+    def _clicked(self, drawable, x, y, z, button, time, pressure):
         if self._dragging and self._drag_accum > self.drag_threshold:
             return True
 
-        return self.emit('clicked', x, y, z, button, time)
+        return self.emit('clicked', x, y, z, button, time, pressure)
 
     def _double_clicked(self, drawable, x, y, z, button, time):
         if self._dragging:
@@ -437,7 +437,7 @@ class Grid(Group):
     def __getitem__(self, index):
         return self.widgets[index]
 
-    def do_clicked(self, x, y, z, button, time):
+    def do_clicked(self, x, y, z, button, time, pressure):
         if self._orientation == const.HORIZONTAL:
             column_offset = self.visible_range_start
             row_offset = 0
@@ -459,7 +459,7 @@ class Grid(Group):
     def do_double_clicked(self, x, y, z, button, time):
         return True
 
-    def do_drag_begin(self, x, y, z, button, time):
+    def do_drag_begin(self, x, y, z, button, time, pressure):
         self._initial = (x, y, time)
         self._animated.stop_animations()
         self._stop_deceleration()
@@ -470,7 +470,7 @@ class Grid(Group):
 
         return True
 
-    def do_drag_motion(self, x, y, z, button, time):
+    def do_drag_motion(self, x, y, z, button, time, pressure):
         motion = 0
 
         if self._orientation == const.VERTICAL:
