@@ -97,25 +97,25 @@ class List(Group):
     def _scrolled(self, drawable, x, y, z, direction, time):
         return self.emit('scrolled', x, y, z, direction, time)
 
-    def _drag_begin(self, drawable, x, y, z, button, time):
+    def _drag_begin(self, drawable, x, y, z, button, time, pressure):
         self._dragging = True
-        return self.emit('drag-begin', x, y, z, button, time)
+        return self.emit('drag-begin', x, y, z, button, time, pressure)
 
-    def _drag_motion(self, drawable, x, y, z, button, time):
+    def _drag_motion(self, drawable, x, y, z, button, time, pressure):
         time_since_last = time - self._last_drag_motion
         if time_since_last > self.drag_motion_resolution:
             self._last_drag_motion = time
-            return self.emit('drag-motion', x, y, z, button, time)
+            return self.emit('drag-motion', x, y, z, button, time, pressure)
 
     def _drag_end(self, drawable, x, y, z, button, time):
         self._dragging = False
         return self.emit('drag-end', x, y, z, button, time)
 
-    def _clicked(self, drawable, x, y, z, button, time):
+    def _clicked(self, drawable, x, y, z, button, time, pressure):
         if self._dragging and self._drag_accum > self.drag_threshold:
             return True
 
-        return self.emit('clicked', x, y, z, button, time)
+        return self.emit('clicked', x, y, z, button, time, pressure)
 
     def _double_clicked(self, drawable, x, y, z, button, time):
         if self._dragging:
@@ -412,7 +412,7 @@ class List(Group):
     def __getitem__(self, index):
         return self.widgets[index]
 
-    def do_clicked(self, x, y, z, button, time):
+    def do_clicked(self, x, y, z, button, time, pressure):
         if self._orientation == const.VERTICAL:
             visible_selected = \
                     (y - self.y) / (self.height / self.visible_range_size)
@@ -428,7 +428,7 @@ class List(Group):
     def do_double_clicked(self, x, y, z, button, time):
         return True
 
-    def do_drag_begin(self, x, y, z, button, time):
+    def do_drag_begin(self, x, y, z, button, time, pressure):
         self._initial = (x, y, time)
         self._animated.stop_animations()
         self._stop_deceleration()
@@ -439,7 +439,7 @@ class List(Group):
 
         return True
 
-    def do_drag_motion(self, x, y, z, button, time):
+    def do_drag_motion(self, x, y, z, button, time, pressure):
         motion = 0
 
         if self._orientation == const.VERTICAL:
